MFLocationComponent class

Constructors

MFLocationComponent({required double latitude, required double longitude, String? alias})
Creates a geographical location specified in degrees latitude, longitude and alias.
const

Properties

alias String?
Location alias.
final
hashCode int
The hash code for this object.
no setterinherited
latitude double
The latitude in degrees between -90.0 and 90.0, both inclusive.
final
longitude double
The longitude in degrees between -180.0 (inclusive) and 180.0 (exclusive).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) MFLocationComponent?
Initialize a MFLocationComponent from json object.